<?php

class GalleryHelper
{
    var $_absolutePath;
    var $_embedUri;
    var $_embedPath;
    var $_relativePath;
    var $_title;
    var $_css;
    var $_javascript;
    var $_body;
    var $_error;

    function GalleryHelper($absolutePath, $embedUri, $embedPath, $relativePath)
    {
        $this->_absolutePath = $absolutePath;
        $this->_embedUri = $embedUri;
        $this->_embedPath = $embedPath;
        $this->_relativePath = $relativePath;
    }

    function getGallery($sidebarEnabled, $sidebarGreetingEnabled, $pathbarEnabled)
    {
        require_once($this->_absolutePath);

        // Set up the gallery call
        $ret = GalleryEmbed::init(array('embedUri' => $this->_embedUri,
					  'g2Uri' => $this->_relativePath,
					  'loginRedirect' => '/index.php',
                                          'activeUserId' => ''));

        // Return error details if there is a problem
        if ($ret != null) {
            $this->_error = $ret->getAsHtml();
            return;
        }

        // Set gallery options
        GalleryCapabilities::set('showSidebar', $sidebarEnabled);
        GalleryCapabilities::set('showSidebarGreeting', $sidebarGreetingEnabled);
        GalleryCapabilities::set('showPathbar', $pathbarEnabled);

        // Process the request
        $g2data = GalleryEmbed::handleRequest();

        // Gallery has already sent output (redirect or binary data)
        if ($g2data['isDone']) {
            exit;
        }

        // Retrieve the html head
        if (isset($g2data['headHtml'])) {
            list($title, $css, $javascript) = GalleryEmbed::parseHead($g2data['headHtml']);
            $this->_title = $title;
            $this->_css = $css;
            $this->_javascript = $javascript;
        }

        // Tell gallery that you are done
        $ret = GalleryEmbed::done();

        // Check for errors
        if ($ret != null) {
            return $ret->getAsHtml();
        }

        // Retrieve the html body
        $this->_body = $g2data['bodyHtml'];
    }

    function getImageBlock($blocks, $show, $itemid, $embedMode, $galleryUrl)
    {
        require_once($this->_absolutePath);

        // Set up the gallery call

        $ret = GalleryEmbed::init(array('embedUri' => $this->_embedUri,
					  'g2Uri' => $this->_relativePath,
					  'loginRedirect' => '/index.php',
					  'activeUserId' => '',
					  'fullInit' => true));

        // Check for errors
        if ($ret != null) {
            return $ret->getAsHtml();
        }

        if (!$embedMode) {
            // Tell gallery that you are done
            $ret = GalleryEmbed::done();

            $item_param = '';
            if ( $itemid != "" ) {
                if (is_numeric($itemid) == false)
                    list($ret, $itemid) = GalleryCoreApi::fetchItemIdByPath($itemid);
                $item_param = "&g2_itemId=$itemid";
            }
            return file_get_contents("$galleryUrl?g2_view=imageblock.External&g2_blocks=$blocks&g2_show=$show$item_param", "r");
        }

        // Get the image block
        if ($itemid != "") {
            if (is_numeric($itemid) == false) {
                list($ret, $itemid) = GalleryCoreApi::fetchItemIdByPath($itemid);
            }
            list($ret, $g2data) = GalleryEmbed::getImageBlock(array('blocks' => $blocks,
								      'show' => $show,
								      'itemId' => $itemid));
        } else {
            list($ret, $g2data) = GalleryEmbed::getImageBlock(array('blocks' => $blocks,
								      'show' => $show));
        }

        // Check for errors
        if ($ret != null) {
            return $ret->getAsHtml();
        }

        // Tell gallery that you are done
        $ret = GalleryEmbed::done();

        // Check for errors
        if ($ret != null) {
            return $ret->getAsHtml();
        }

        return $g2data;
    }

    function getTitle()
    {
        return $this->_title;
    }

    function getCSS()
    {
        return $this->_css;
    }

    function getJavascript()
    {
        return $this->_javascript;
    }

    function getBody()
    {
        return $this->_body;
    }

    function getError()
    {
        return $this->_error;
    }
}
